achievement

# XMLRésuméLibrary: User Guide

academics | Element Reference | achievements

## Name

achievement — An accomplishment made at a job

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `achievment` element contains a single accomplishment made while working at a particular job (e.g. “increased sales by 20%”, or “improved employee efficiency”).

### Parents

`achievement` may be contained in these elements: `achievements`

## Examples

    <job>
      <jobtitle>Eggroll Engineer</jobtitle>
      <employer>Chineese Cuisine Systems, Inc.</employer>
      <period>
        <from>
          <date>
            <month>August</month>
            <year>1993</year>
          </date>
        </from>
        <to>
          <present/>
        </to>
      </period>
      <achievements>
        <achievement>
          Wrote an <emphasis>excellent</emphasis> article on shell crispiness for
          the <citation>European Journal of Egg Food Engineering</citation>,
          published at <url>http://www.ejeps.org/articles/crispiness.html</url>.
        </achievement>
        <achievement>
          Decreased filling greasiness by a <emphasis>whopping</emphasis> 30%!
        </achievement>
      </achievements>
    </job>

academics | Element Reference | achievements